@@ -13,5 +13,5 @@ void
 on_okbutton1_released                  (GtkButton       *button,
                                         gpointer         user_data)
 {
-    system("killall matchbox-panel");
+    system("killall matchbox-panel 2>/dev/null || killall openbox 2>/dev/null");
 }
